==> logdissect-3.0.1.tar.gz: logdissect-3.0.1/logdissect/parsers/__init__.py <==
# MIT License
# 
# Copyright (c) 2017 Dan Persons <dpersonsdev@gmail.com>
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

__all__ = ['syslog', 'syslogiso', 'syslognohost', 'linejson', 'tcpdump',
        'ciscoios', 'windowsrsyslog', 'sojson', 'webaccess']

import logdissect.parsers.linejson
import logdissect.parsers.sojson
import logdissect.parsers.syslog
import logdissect.parsers.syslogiso
import logdissect.parsers.syslognohost
import logdissect.parsers.tcpdump
import logdissect.parsers.ciscoios
import logdissect.parsers.windowsrsyslog
import logdissect.parsers.webaccess

==> logdissect-3.1.tar.gz: logdissect-3.1/logdissect/parsers/__init__.py <==
# MIT License
# 
# Copyright (c) 2017 Dan Persons <dpersonsdev@gmail.com>
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

__all__ = ['syslog', 'syslogiso', 'syslognohost', 'linejson', 'tcpdump',
        'ciscoios', 'windowsrsyslog', 'sojson', 'webaccess', 'emerge']

import logdissect.parsers.blank
import logdissect.parsers.linejson
import logdissect.parsers.sojson
import logdissect.parsers.syslog
import logdissect.parsers.syslogiso
import logdissect.parsers.syslognohost
import logdissect.parsers.tcpdump
import logdissect.parsers.ciscoios
import logdissect.parsers.windowsrsyslog
import logdissect.parsers.webaccess
import logdissect.parsers.emerge
